// I18N constants

// Translation Note
// 1. translate the left  side of fontname, font size and formatblock
// 2. translate the right side of tooltips

HTMLArea.I18N = {
	fontname: {
		"Ҧ":            'arial,helvetica,sans-serif',
		" '":     'courier new,courier,monospace',
		"֦":          'georgia,times new roman,times,serif',
		"":           'tahoma,arial,helvetica,sans-serif',
		"  ": 'times new roman,times,serif',
		"":          'verdana,arial,helvetica,sans-serif',
		"":        'impact',
		"WingDings":        'wingdings'
	},

	fontsize: {
		"1 (8 pt)":  "1",
		"2 (10 pt)": "2",
		"3 (12 pt)": "3",
		"4 (14 pt)": "4",
		"5 (18 pt)": "5",
		"6 (24 pt)": "6",
		"7 (36 pt)": "7"
	},

	formatblock: {
		" 1": "h1",
		" 2": "h2",
		" 3": "h3",
		" 4": "h4",
		" 5": "h5",
		" 6": "h6",
		"": "p",
		"": "address",
		"צ": "pre"
	},

	tooltips: {
		bold:           "",
		italic:         "",
		underline:      "Ц",
		strikethrough:  "",
		subscript:      "Ц",
		superscript:    "",
		justifyleft:    "Ҧ ̦",
		justifycenter:  "Ҧ  ",
		justifyright:   "Ҧ ̦",
		justifyfull:    "",
		insertorderedlist:    " ",
		insertunorderedlist:  "",
		outdent:        " צ",
		indent:         "¦ צ",
		forecolor:      "̦ ",
		hilitecolor:    "̦ ",
		inserthorizontalrule: " ",
		createlink:     " ",
		insertimage:    " ",
		insertsound:    " ",
		inserttable:    " ",
		htmlmode:       "   HTML-",
		popupeditor:    "¦ ",
		about:          "  ",
		showhelp:       "צ  ",
		textindicator:  " ",
		undo:           "Undoes your last action",
		redo:           "Redoes your last action",
		cut:            "Cut selection",
		copy:           "Copy selection",
		paste:          "Paste from clipboard"
	},

	buttons: {
		"ok":           "OK",
		"cancel":       "Cancel"
	},

	msg: {
		"Path":         "Path",
		"TEXT_MODE":    "You are in TEXT MODE.  Use the [<>] button to switch back to WYSIWIG."
	}
};
